@@ -12,7 +12,7 @@ class SourceConfig(object):
     ConfigKeys = DBTConfigKeys
 
     AppendListFields = ['pre-hook', 'post-hook']
-    ExtendDictFields = ['vars']
+    ExtendDictFields = ['vars', 'column_types', 'quoting']
     ClobberFields = [
         'schema',
         'enabled',
@@ -68,11 +68,17 @@ class SourceConfig(object):
            - active project config
            - in-model config
         """
+
         defaults = {"enabled": True, "materialized": "view"}
+
+        if self.node_type == NodeType.Seed:
+            defaults['materialized'] = 'seed'
+
         active_config = self.load_config_from_active_project()
 
         if self.active_project['name'] == self.own_project['name']:
-            cfg = self._merge(defaults, active_config, self.in_model_config)
+            cfg = self._merge(defaults, active_config,
+                              self.in_model_config)
         else:
             own_config = self.load_config_from_own_project()
 
