@@ -14,7 +14,6 @@ import dbt.schema
 import dbt.templates
 import dbt.writer
 
-import os
 import time
 
 
@@ -80,7 +79,7 @@ class BaseRunner(object):
 
     @classmethod
     def is_refable(cls, node):
-        return node.get('resource_type') in [NodeType.Model, NodeType.Seed]
+        return node.get('resource_type') in NodeType.refable()
 
     @classmethod
     def is_ephemeral(cls, node):
@@ -90,7 +89,7 @@ class BaseRunner(object):
     def is_ephemeral_model(cls, node):
         return cls.is_refable(node) and cls.is_ephemeral(node)
 
-    def safe_run(self, flat_graph, existing):
+    def safe_run(self, flat_graph):
         catchable_errors = (dbt.exceptions.CompilationException,
                             dbt.exceptions.RuntimeException)
 
@@ -105,7 +104,7 @@ class BaseRunner(object):
 
             # for ephemeral nodes, we only want to compile, not run
             if not self.is_ephemeral_model(self.node):
-                result = self.run(compiled_node, existing, flat_graph)
+                result = self.run(compiled_node, flat_graph)
 
         except catchable_errors as e:
             if e.node is None:
@@ -148,11 +147,11 @@ class BaseRunner(object):
     def before_execute(self):
         raise NotImplementedException()
 
-    def execute(self, compiled_node, existing, flat_graph):
+    def execute(self, compiled_node, flat_graph):
         raise NotImplementedException()
 
-    def run(self, compiled_node, existing, flat_graph):
-        return self.execute(compiled_node, existing, flat_graph)
+    def run(self, compiled_node, flat_graph):
+        return self.execute(compiled_node, flat_graph)
 
     def after_execute(self, result):
         raise NotImplementedException()
@@ -209,7 +208,7 @@ class CompileRunner(BaseRunner):
     def after_execute(self, result):
         pass
 
-    def execute(self, compiled_node, existing, flat_graph):
+    def execute(self, compiled_node, flat_graph):
         return RunModelResult(compiled_node)
 
     def compile(self, flat_graph):
@@ -251,33 +250,34 @@ class CompileRunner(BaseRunner):
 
         def call_get_columns_in_table(schema_name, table_name):
             return adapter.get_columns_in_table(
-                profile, schema_name, table_name, node.get('name'))
+                profile, project, schema_name,
+                table_name, model_name=node.get('name'))
 
         def call_get_missing_columns(from_schema, from_table,
                                      to_schema, to_table):
             return adapter.get_missing_columns(
-                profile, from_schema, from_table,
+                profile, project, from_schema, from_table,
                 to_schema, to_table, node.get('name'))
 
-        def call_table_exists(schema, table):
-            return adapter.table_exists(
-                profile, schema, table, node.get('name'))
+        def call_already_exists(schema, table):
+            return adapter.already_exists(
+                profile, project, schema, table, node.get('name'))
 
         return {
             "run_started_at": dbt.tracking.active_user.run_started_at,
             "invocation_id": dbt.tracking.active_user.invocation_id,
             "get_columns_in_table": call_get_columns_in_table,
             "get_missing_columns": call_get_missing_columns,
-            "already_exists": call_table_exists,
+            "already_exists": call_already_exists,
         }
 
     @classmethod
     def create_schemas(cls, project, adapter, flat_graph):
         profile = project.run_environment()
         required_schemas = cls.get_model_schemas(flat_graph)
-        existing_schemas = set(adapter.get_existing_schemas(profile))
+        existing_schemas = set(adapter.get_existing_schemas(profile, project))
         for schema in (required_schemas - existing_schemas):
-            adapter.create_schema(profile, schema)
+            adapter.create_schema(profile, project, schema)
 
 
 class ModelRunner(CompileRunner):
@@ -292,41 +292,42 @@ class ModelRunner(CompileRunner):
         nodes = flat_graph.get('nodes', {}).values()
         hooks = get_nodes_by_tags(nodes, {hook_type}, NodeType.Operation)
 
-        # This will clear out an open transaction if there is one.
-        # on-run-* hooks should run outside of a transaction. This happens b/c
-        # psycopg2 automatically begins a transaction when a connection is
-        # created. TODO : Move transaction logic out of here, and implement
-        # a for-loop over these sql statements in jinja-land. Also, consider
-        # configuring psycopg2 (and other adapters?) to ensure that a
-        # transaction is only created if dbt initiates it.
-        conn_name = adapter.clear_transaction(profile)
+        ordered_hooks = sorted(hooks, key=lambda h: h.get('index', len(hooks)))
 
-        compiled_hooks = []
-        for hook in hooks:
+        for i, hook in enumerate(ordered_hooks):
+            model_name = hook.get('name')
+
+            # This will clear out an open transaction if there is one.
+            # on-run-* hooks should run outside of a transaction. This happens
+            # b/c psycopg2 automatically begins a transaction when a connection
+            # is created. TODO : Move transaction logic out of here, and
+            # implement a for-loop over these sql statements in jinja-land.
+            # Also, consider configuring psycopg2 (and other adapters?) to
+            # ensure that a transaction is only created if dbt initiates it.
+            adapter.clear_transaction(profile, model_name)
             compiled = cls._compile_node(adapter, project, hook, flat_graph)
-            model_name = compiled.get('name')
             statement = compiled['wrapped_sql']
 
             hook_index = hook.get('index', len(hooks))
             hook_dict = dbt.hooks.get_hook_dict(statement, index=hook_index)
-            compiled_hooks.append(hook_dict)
 
-        ordered_hooks = sorted(compiled_hooks, key=lambda h: h.get('index', 0))
-
-        for hook in ordered_hooks:
             if dbt.flags.STRICT_MODE:
-                dbt.contracts.graph.parsed.validate_hook(hook)
+                dbt.contracts.graph.parsed.validate_hook(hook_dict)
 
-            sql = hook.get('sql', '')
-            adapter.execute_one(profile, sql, model_name=conn_name,
-                                auto_begin=False)
-            adapter.release_connection(profile, conn_name)
+            sql = hook_dict.get('sql', '')
+
+            if len(sql.strip()) > 0:
+                adapter.execute_one(profile, sql, model_name=model_name,
+                                    auto_begin=False)
+
+            adapter.release_connection(profile, model_name)
 
     @classmethod
     def safe_run_hooks(cls, project, adapter, flat_graph, hook_type):
         try:
             cls.run_hooks(project, adapter, flat_graph, hook_type)
-        except dbt.exceptions.RuntimeException as e:
+
+        except dbt.exceptions.RuntimeException:
             logger.info("Database error while running {}".format(hook_type))
             raise
 
@@ -339,12 +340,12 @@ class ModelRunner(CompileRunner):
         # is the one defined in the profile. Create this schema if it
         # does not exist, otherwise subsequent queries will fail. Generally,
         # dbt expects that this schema will exist anyway.
-        required_schemas.add(adapter.get_default_schema(profile))
+        required_schemas.add(adapter.get_default_schema(profile, project))
 
-        existing_schemas = set(adapter.get_existing_schemas(profile))
+        existing_schemas = set(adapter.get_existing_schemas(profile, project))
 
         for schema in (required_schemas - existing_schemas):
-            adapter.create_schema(profile, schema)
+            adapter.create_schema(profile, project, schema)
 
     @classmethod
     def before_run(cls, project, adapter, flat_graph):
@@ -401,8 +402,9 @@ class ModelRunner(CompileRunner):
         track_model_run(self.node_index, self.num_nodes, result)
         self.print_result_line(result)
 
-    def execute(self, model, existing, flat_graph):
-        context = dbt.context.runtime.generate(model, self.project, flat_graph)
+    def execute(self, model, flat_graph):
+        context = dbt.context.runtime.generate(
+            model, self.project.cfg, flat_graph)
 
         materialization_macro = dbt.utils.get_materialization_macro(
             flat_graph,
@@ -461,7 +463,7 @@ class TestRunner(CompileRunner):
     def before_execute(self):
         self.print_start_line()
 
-    def execute(self, test, existing, flat_graph):
+    def execute(self, test, flat_graph):
         status = self.execute_test(test)
         return RunModelResult(test, status=status)
 
@@ -499,20 +501,6 @@ class SeedRunner(ModelRunner):
         dbt.ui.printer.print_start_line(description, self.node_index,
                                         self.num_nodes)
 
-    def execute(self, compiled_node, existing_, flat_graph):
-        schema = compiled_node["schema"]
-        table_name = compiled_node["name"]
-        table = compiled_node["agate_table"]
-        self.adapter.handle_csv_table(self.profile, schema, table_name, table,
-                                      full_refresh=dbt.flags.FULL_REFRESH)
-
-        if dbt.flags.FULL_REFRESH:
-            status = 'CREATE {}'.format(len(table.rows))
-        else:
-            status = 'INSERT {}'.format(len(table.rows))
-
-        return RunModelResult(compiled_node, status=status)
-
     def compile(self, flat_graph):
         return self.node
 
