@@ -288,10 +288,8 @@ def parse_sql_nodes(nodes, root_project, projects, tags=None, macros=None):
         # Check for duplicate model names
         existing_node = to_return.get(node_path)
         if existing_node is not None:
-            raise dbt.exceptions.CompilationException(
-                'Found models with the same name:\n- %s\n- %s' % (
-                    existing_node.get('original_file_path'),
-                    node.get('original_file_path')))
+            dbt.exceptions.raise_duplicate_resource_name(
+                    existing_node, node_parsed)
 
         to_return[node_path] = node_parsed
 
