@@ -2,12 +2,10 @@ import os.path
 import os
 import shutil
 
+from dbt.task.base_task import BaseTask
 
-class CleanTask:
 
-    def __init__(self, args, project):
-        self.args = args
-        self.project = project
+class CleanTask(BaseTask):
 
     def __is_project_path(self, path):
         proj_path = os.path.abspath('.')
