@@ -9,7 +9,7 @@ from dbt.logger import GLOBAL_LOGGER as logger
 from dbt.task.base_task import BaseTask
 
 STARTER_REPO = 'https://github.com/fishtown-analytics/dbt-starter-project.git'
-DOCS_URL = 'https://dbt.readme.io/docs/configure-your-profile'
+DOCS_URL = 'https://docs.getdbt.com/docs/configure-your-profile'
 SAMPLE_PROFILES_YML_FILE = 'https://github.com/fishtown-analytics/dbt/blob/master/sample.profiles.yml'  # noqa
 
 ON_COMPLETE_MESSAGE = """
