@@ -26,7 +26,9 @@ DBTConfigKeys = [
     'pre-hook',
     'post-hook',
     'vars',
+    'column_types',
     'bind',
+    'quoting',
 ]
 
 
@@ -36,52 +38,6 @@ class ExitCodes(object):
     UnhandledError = 2
 
 
-class Relation(object):
-    def __init__(self, profile, adapter, node, use_temp=False):
-        self.node = node
-        self.schema = node.get('schema')
-        self.name = node.get('name')
-
-        if use_temp:
-            self.table = self._get_table_name(node)
-        else:
-            self.table = self.name
-
-        self.materialized = get_materialization(node)
-        self.sql = node.get('injected_sql')
-
-        self.do_quote = self._get_quote_function(profile, adapter)
-
-    def _get_quote_function(self, profile, adapter):
-
-        # make a closure so we don't need to store the profile
-        # on the `Relation` object. That shouldn't be accessible in user-land
-        def quote(schema, table):
-            return adapter.quote_schema_and_table(
-                        profile=profile,
-                        schema=schema,
-                        table=table
-                    )
-
-        return quote
-
-    def _get_table_name(self, node):
-        return model_immediate_name(node, dbt.flags.NON_DESTRUCTIVE)
-
-    def final_name(self):
-        if self.materialized == 'ephemeral':
-            msg = "final_name() was called on an ephemeral model"
-            dbt.exceptions.raise_compiler_error(msg, self.node)
-        else:
-            return self.do_quote(self.schema, self.name)
-
-    def __repr__(self):
-        if self.materialized == 'ephemeral':
-            return '__dbt__CTE__{}'.format(self.name)
-        else:
-            return self.do_quote(self.schema, self.table)
-
-
 def coalesce(*args):
     for arg in args:
         if arg is not None:
@@ -89,6 +45,12 @@ def coalesce(*args):
     return None
 
 
+def chunks(l, n):
+    """Yield successive n-sized chunks from l."""
+    for i in range(0, len(l), n):
+        yield l[i:i + n]
+
+
 def get_profile_from_project(project):
     target_name = project.get('target', {})
     profile = project.get('outputs', {}).get(target_name, {})
@@ -117,9 +79,18 @@ def compiler_warning(model, msg):
 
 
 def model_immediate_name(model, non_destructive):
-    "The name of the model table/view within the transaction"
+    """
+    Returns the name of the model relation within the transaction. This is
+    useful for referencing the model in pre or post hooks. Non-destructive
+    models aren't created with temp suffixes, nor are incremental models or
+    seeds.
+    """
+
     model_name = model.get('name')
-    if non_destructive or get_materialization(model) == 'incremental':
+    is_incremental = (get_materialization(model) == 'incremental')
+    is_seed = is_type(model, 'seed')
+
+    if non_destructive or is_incremental or is_seed:
         return model_name
     else:
         return "{}__dbt_tmp".format(model_name)
@@ -127,7 +98,7 @@ def model_immediate_name(model, non_destructive):
 
 def find_refable_by_name(flat_graph, target_name, target_package):
     return find_by_name(flat_graph, target_name, target_package,
-                        'nodes', [NodeType.Model, NodeType.Seed])
+                        'nodes', NodeType.refable())
 
 
 def find_macro_by_name(flat_graph, target_name, target_package):
@@ -434,3 +405,12 @@ def parse_cli_vars(var_string):
         logger.error(
                 "The YAML provided in the --vars argument is not valid.\n")
         raise
+
+
+def filter_null_values(input):
+    return dict((k, v) for (k, v) in input.items()
+                if v is not None)
+
+
+def add_ephemeral_model_prefix(s):
+    return '__dbt__CTE__{}'.format(s)
