@@ -38,6 +38,8 @@ class CompilerTest(unittest.TestCase):
             'post-hook': [],
             'pre-hook': [],
             'vars': {},
+            'quoting': {},
+            'column_types': {},
         }
 
     def test__prepend_ctes__already_has_cte(self):
