@@ -28,6 +28,7 @@ class ParserTest(unittest.TestCase):
             'profile': 'test',
             'project-root': os.path.abspath('.'),
             'target': 'test',
+            'quoting': {},
             'outputs': {
                 'test': {
                     'type': 'postgres',
@@ -42,6 +43,7 @@ class ParserTest(unittest.TestCase):
             'version': '0.1',
             'project-root': os.path.abspath('./dbt_modules/snowplow'),
             'target': 'test',
+            'quoting': {},
             'outputs': {
                 'test': {
                     'type': 'postgres',
@@ -57,6 +59,8 @@ class ParserTest(unittest.TestCase):
             'post-hook': [],
             'pre-hook': [],
             'vars': {},
+            'quoting': {},
+            'column_types': {},
         }
 
         self.disabled_config = {
@@ -65,6 +69,8 @@ class ParserTest(unittest.TestCase):
             'post-hook': [],
             'pre-hook': [],
             'vars': {},
+            'quoting': {},
+            'column_types': {},
         }
 
     def test__single_model(self):
